var assert = require('chai').assert;
var should = require('chai').should;
var Kickstarter = require('../../bin/classes/kickstarter');
var Controller = require('../../bin/core/controller');
var commandContext = require('../../bin/core/commandContext');

describe("Test suite for the kickstarter class.", function(){
    it("The kickstarter should throw an error if instantiated without action parameter", function(){
        
        function instantiate () {
            var ks = new Kickstarter();
        }

        assert.throws(instantiate,Error);
    })

    it("should create a new controller object at instantiation.", function () {
        
            var ks = new Kickstarter('testMode');
            assert.equal((ks.ctrl instanceof Controller), true);
            
    })

    it("should have access to a commandContext through the new controller object", function () {
        
            var ks = new Kickstarter('testMode');
            var ctxt = ks.ctrl.getContext();
            assert.equal((ctxt instanceof commandContext), true);            
    })

    it("should set a context value for the user's config filepath",function(){
            var ks = new Kickstarter('testMode');
            var ctxt = ks.ctrl.getContext();
            assert.equal((ctxt.parameters.userConfigFile === "../../test/testEnv/bin/mc/config/config.json" ), true); 
    })

    it("should set a context value for the user's configuration",function(){
            var ks = new Kickstarter('testMode');
            var ctxt = ks.ctrl.getContext();
            assert.equal((ctxt.parameters.userConfiguration.hasOwnProperty('macros')), true); 
    })

    it("should set a context value for the user's helper directory",function(){
            var ks = new Kickstarter('testMode');
            var ctxt = ks.ctrl.getContext();
            assert.equal((ctxt.parameters.userHelperDir === "./test/testEnv/bin/mc/helper"), true); 
    })

    it("should set a context value for the user's commands directory",function(){
            var ks = new Kickstarter('testMode');
            var ctxt = ks.ctrl.getContext();
            assert.equal((ctxt.parameters.userCommandsRootDir === "./test/testEnv/bin/mc/commands"), true); 
    })


});