var assert = require('chai').assert;
var should = require('chai').should;
const expect = require('chai').expect;
var Command = require('../../bin/commands/command');
var TestCommand1 = require('../testEnv/bin/mc/commands/testCommand1');
var CommandContext = require('../../bin/core/commandContext');

describe("Test suite for the abstract 'command' class", function () {

    it("The command class should throw an error if instantiated,\n       because it is abstract.", function () {

        function instantiate() {
            var cmd = new Command;
        }

        assert.throws(instantiate, Error);
    });

    it("The execute method should throw an error if no context is available", function () {
        function instantiate() {
            var cmd = new DefaultCommand;
            var result = cmd.execute();

        }
        assert.throws(instantiate, Error);

    });

    it("The execute method should throw an error if context is of the wrong type.", function () {
        function instantiate() {

            var paramOfWrongType = "justAString";
            var cmd = new DefaultCommand;
            var result = cmd.execute(paramOfWrongType);
            return result;

        }
        assert.throws(instantiate, Error);

    });

    it("The execute method should return a promise with a value of type commandResult.", function () {

        var ctxt = new CommandContext();
        ctxt.parameters.action = 'macro';
        ctxt.parameters.macroID = 1;
        var cmd = new TestCommand1;
        cmd.execute(ctxt).then((value) => {
             expect(value).to.have.property('msg')
                .that.is.a('string');
        });
    });

    //todo: write test for the findPrevResult() method

});